Documentation
¶
Overview ¶
Package expandInDBCommon contains common functions for expandInDBDepth and expandInDBSeq packages.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ProcessScalarField ¶
ProcessScalarField generates operations that process scalar field in aggregation pipeline.
func ProcessStringField ¶
ProcessStringField generates operations that process string field in aggregation pipeline.
Types ¶
Click to show internal directories.
Click to hide internal directories.